textstats_metadataerror
open | / |
type | projectname | seleniumtest
clickAndWait | startprojectbutton |
verifyTextPresent | Accepting new input files and selection of parameters |
click | openeditor |
type | editorcontents | Dit is een test.
select | editorinputtemplate | label=Input text document
select | language | label=Dutch
type | author | Maarten van Gompel
type | year | 20100
type | editorfilename | test
click | editorsubmit |
waitForTextPresent | Number must be a whole number between |
type | year | 2010
click | editorsubmit |
waitForTextPresent | test.txt |
clickAndWait | abortbutton |
verifyTextPresent | Start a new Project |